@@ -9,13 +9,20 @@ class RecipeConstraints:
 
 
 @dataclass
-class RecipeInformation:
+class Printable:
     title: str = ""
     ingredients: str = ""
     preparation: str = ""
     error_message: Optional[str] = None
+    warning_message: Optional[str] = None
+    info_message: Optional[str] = None
 
 
 @dataclass
 class FetchingError(Exception):
     message: str = "An error ocurred"
+
+
+@dataclass
+class PrintInterrupt(Exception):
+    printable: Printable
